import React, { useState, useEffect } from "react";
import { Breadcrumb, Layout, Menu, Avatar, Badge, Space, Dropdown, Row, Col } from "antd";
import { Route, Link } from "react-router-dom";
import {
  DownOutlined,
  SettingOutlined,
  LoginOutlined,
  MehOutlined,
  MenuUnfoldOutlined,
  MenuFoldOutlined,
  UserOutlined,
  MessageOutlined
} from "@ant-design/icons";
import "./index.scss";
import { routes, BreadcrumbNameMap } from "../router/config";
import "@ant-design/pro-table/dist/table.css";
import logo from "../assets/img/logo.png";
import MiniLogo from "../assets/img/miniLog.png";

const { SubMenu } = Menu;
const allHistory = {};
const { Header, Content, Sider } = Layout;

const reallyRoutes = routes
  .map((item) => (item.children ? [item, ...item.children] : item))
  .flat();
const AdminLayout: any = (props: any) => {
  const [currentKeys, setCurrentKeys]: any = useState(["/admin/role"]);
  const [collapsed, setState] = React.useState(false);
  const [scrollState, setscrollState] = useState("")
  const handleToggle = () => {
    setState(!collapsed);
  };

  const handleLogOut = () => {
    window.sessionStorage.clear();
    window.location.href = "/login";
  };
  const switchRoute = (route) => {
    props.history.push(route.path);
    setCurrentKeys([route.path]);
  };
  const cancelScorllbar = () => {
    setscrollState('sider-roll')
  };
  const showScorllbar = () => {
    setscrollState('')
  };

  useEffect(() => {
    setCurrentKeys([props.history.location.pathname]);
  }, [props.history.location.pathname]);

  const paths = props.history.location.pathname.split("/").filter((i) => i);
  const arr: any = []
  paths.map((_, index) => {
    const url = "/" + paths.slice(0, index + 1).join("/");
    arr.push(url)
  });
  const newArr = arr.slice(1, 2)
  const residueArr = arr.slice(2)
  const breadcrumbItems = residueArr.map(item => {
    return (
      <>
        <Breadcrumb.Item href={item} key={item}>
          {BreadcrumbNameMap[item]}
        </Breadcrumb.Item>
      </>
    );
  })

  return (
    <Layout style={{ minHeight: "100vh" }} >
      <Sider
        className={scrollState}
        trigger={null}
        collapsible
        collapsed={collapsed}
        style={{
          overflow: "auto",
          height: "100vh",
          position: "fixed",
          left: 0,
          background: "#222328"
        }}
        onMouseLeave={cancelScorllbar}
        onMouseEnter={showScorllbar}
      >
        <div className="header-logo">
          <Link to="/home">
            {collapsed ? (
              <img className="logo" src={MiniLogo} alt="" key={'MiniLogo'} />
            ) : (
              <img className="logo" src={logo} alt="" key={'logo'} />
            )}
          </Link>
        </div>
        <Menu mode="inline" selectedKeys={currentKeys} theme="dark" >
          {routes
            .filter((item) => !item.hideInMenu)
            .map((route) => {
              return route.children &&
                route.children.filter(({ hideInMenu }) => !hideInMenu)
                  ?.length ? (
                <Menu.SubMenu
                  key={route.path}
                  title={route.title}
                  icon={route.icon}
                >
                  {route.children
                    .filter((item) => !item.hideInMenu)
                    .map((child) => (
                      <Menu.Item
                        key={child.path}
                        onClick={() => switchRoute(child)}
                      >
                        {child.title}
                      </Menu.Item>
                    ))}
                </Menu.SubMenu>
              ) : (
                <Menu.Item
                  key={route.path}
                  onClick={() => switchRoute(route)}
                  icon={route.icon}
                >
                  {route.title}
                </Menu.Item>
              );
            })}
        </Menu>
      </Sider>
      <Layout style={{ paddingLeft: collapsed ? 80 : 200 }}>
        <Header className="site-layout-background" style={{ padding: 0 }}>
          {React.createElement(
            collapsed ? MenuUnfoldOutlined : MenuFoldOutlined,
            {
              className: "trigger",
              onClick: handleToggle
            }
          )}
          <Row style={{ width: "100%" }} align="middle">
            <Col span={6} push={18} style={{ display: "flex", justifyContent: "center" }}>
              <Space size="middle">
                <Dropdown
                  overlay={() => {
                    return (
                      <Menu>
                        <Menu.Item key={'setting'}>
                          <Link to="/admin/index">
                            <SettingOutlined /> 个人设置
                          </Link>
                        </Menu.Item>
                        <Menu.Item key={'loginOut'}>
                          <a
                            target="_blank"
                            rel="noopener noreferrer"
                            onClick={handleLogOut}
                          >
                            <LoginOutlined></LoginOutlined>退出
                          </a>
                        </Menu.Item>
                      </Menu>
                    );
                  }}
                >
                  <a
                    className="ant-dropdown-link"
                    onClick={(e) => e.preventDefault()}
                  >
                    <Avatar
                      style={{ backgroundColor: "#87d068" }}
                      icon={<UserOutlined />}
                    />
                    <span
                      className="layout-header-username"
                      style={{ marginLeft: 3 }}
                    >
                      {sessionStorage.getItem("username") || "admin"}
                    </span>
                    <DownOutlined></DownOutlined>
                  </a>
                </Dropdown>
              </Space>
            </Col>
            <Col span={18} pull={6}>
              <Breadcrumb className="header-breadcrumb">
                <Breadcrumb.Item>
                  {BreadcrumbNameMap[newArr[0]]}
                </Breadcrumb.Item>
                {breadcrumbItems}
              </Breadcrumb>
            </Col>
          </Row>
        </Header>
        <Content className="layout-content">
          {reallyRoutes.map((route: any) => (
            <Route
              exact={route.exact}
              path={route.path}
              key={route.path}
              component={route.component}
            />
          ))}
        </Content>
      </Layout>
    </Layout>
  );
};

export default AdminLayout;
