import axios from 'axios'
import { message } from 'antd'

const prefix = '/api/v1'

export const request = axios.create({
  baseURL: `${prefix}`,
  timeout: 50000
})

request.interceptors.request.use(config => {
  if (sessionStorage.getItem('area-token')) {
    config.headers['token'] = sessionStorage.getItem('area-token')
  }
  if (config?.params?.current) {
    config.params.page = config.params.current
    delete config.params.current
  }

  if (config?.params?.pageSize) {
    config.params.page_size = config.params.pageSize
    delete config.params.pageSize
  }

  if (config?.data?.method) {
    delete config.data.method
  }
  return config
})

const errorHandler = code => {
   // login
   if ([10008,10009, 10010].includes(code)) {
    window.location.href = '/login'
  }
}

// request.interceptors.response.use(response => {
//   if (response.data.code) {
//     const error = response.data.message
//     message.error(error)
//     errorHandler(response.data.code)
//     throw error
//   }
//   return response.data
// })
request.interceptors.response.use(response => {
  let res = response.data
  if (!res.code) {
    if (res.data?.list) {
      return {
        success: true,
        data: res.data.list,
        total: res.data.total,
        ...res.data
      }
    }
  }

  if (res.code) {
    const error = res.message
    message.error(error)
    errorHandler(res.code)
    throw error
  }
  return res
},async error => {
  if (error && error.response && error.response.status != 200) {
    message.error("服务器异常")
    throw "服务器异常"
  }
})

export default request
