import React, { useState } from "react";
import { Button, Image, message, Modal, Select, Form } from "antd";
import type { ActionType } from "@ant-design/pro-table";
import { PlusOutlined } from "@ant-design/icons";
import ProTable from "@ant-design/pro-table";
import { Application, ApplicationEnable, Permissions } from "../../../services/application";
import { Link } from "react-router-dom";
import Index from "./permission";
import "./adhibition.scss"

const Adhibition = (props) => {
    const ENABLE = {
        true: { text: '已上架', status: "Success" },
        false: { text: '待上架', status: "Default" }
    }
    const columns: any = [
        {
            title: '应用名',
            align: "center",
            search: false,
            dataIndex: "name"
        },
        {
            title: '应用图标',
            align: "center",
            search: false,
            dataIndex: "icon",
            render: (_, row) => <Image src={row.icon} style={{ width: "50px", height: '50px' }} />
        },
        {
            title: '应用简介',
            align: "center",
            search: false,
            dataIndex: "desc",
            ellipsis: true,
        },
        {
            title: '价格',
            align: "center",
            search: false,
            dataIndex: "price",
            render: (_, row) => row.price / 100
        },
        {
            title: '是否上架',
            align: "center",
            search: false,
            dataIndex: "enable",
            valueEnum: ENABLE
        },
        {
            title: '状态',
            align: "center",
            hideInTable: true,
            valueType: "select",
            valueEnum: {
                1: "已上架",
                2: "待上架"
            }
        },
        {
            title: '操作',
            dataIndex: 'option',
            search: false,
            align: 'center',
            width:"300px",
            render: (_, row, index, action) => <>
                <Button type="link" onClick={() => {
                    form.resetFields()
                    contralModal(true);
                    setState(pre => ({ ...pre, id: row.id }))
                }}>应用菜单</Button>
                <Button type="link" onClick={() => AddedEnable(row.id, row.enable)}>{row.enable ? "下架" : "上架"}</Button>
                <Button type="link" onClick={() => DeleteAdhibition(row.id)}>删除</Button>
                <Link to={{ pathname: "/admin/adhibition/adhibition/edit", state: row }}>
                    <Button type="link">修改</Button>
                </Link>
                <Link to={{ pathname: "/admin/adhibition/adhibition/preview", state: row }}>
                    <Button type="link" >预览</Button>
                </Link>
            </>
        }
    ]
    const actionRef = React.useRef<ActionType>() as any;
    const [state, setState] = useState({
        visible: false,
        id: null,
    })
    const [form] = Form.useForm();
    const AddedEnable = async (id, enable) => {
        await ApplicationEnable({ id, enable: !enable });
        message.success("操作成功");
        actionRef.current?.reloadAndRest();
    }
    const DeleteAdhibition = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await Application({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current?.reloadAndRest();
            }
        });
    }
    const contralModal = (flag) => {
        setState((pre) => ({ ...pre, visible: flag }))
    }
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            const { id } = state;
            console.log(values);
            await Permissions({ id, ...values, method: "put" });
            message.success("操作成功！");
            contralModal(false);
        })

    }
    const getCode = (val) => {
        form.setFieldsValue({ permissions: val })
    }




    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row => row.id}
            request={Application}
            options={false}
            columns={columns}
            toolBarRender={() => [
                <Link to={"/admin/adhibition/adhibition/add"}>
                    <Button
                        type="primary"
                        key="primary"
                        icon={<PlusOutlined />}
                    >
                        新增
                    </Button>
                </Link>
            ]}
        />
        <Modal
            title="应用菜单"
            visible={state.visible}
            width={680}
            onOk={onSubmit}
            maskClosable={false}
            onCancel={() => contralModal(false)}
        >
            <Form form={form}>
                <Form.Item name='permissions' rules={[{ required: true, message: "请选择权限" }]}>
                    <Index id={state.id} getCode={getCode} />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Adhibition