import React, { useEffect, useState } from "react";
import { GetPackage, PKenable } from "../../../services/package";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { Button, Form, Modal, Input, InputNumber, message } from "antd";
import { PlusOutlined } from "@ant-design/icons";
import TextArea from "antd/lib/input/TextArea";
import { Link } from "react-router-dom";

const Combo = () => {
    const ENABLE = {
        true: {text:'已发布',status:"Success"},
        false: {text:'待发布',status:"Default"}
    }
    const columns: any = [
        {
            title: '套餐名',
            search: false,
            align: "center",
            dataIndex: "name"
        },
        {
            title: '套餐简介',
            search: false,
            align: "center",
            dataIndex: "desc",
            ellipsis: true,
        },
        {
            title: '套餐价格(元）',
            search: false,
            align: "center",
            dataIndex: "price",
            render: (_, row) => row.price / 100
        },
        {
            title: '包含房间数',
            search: false,
            align: "center",
            dataIndex: "house_count"
        },
        {
            title: '是否发布',
            align: "center",
            dataIndex: "enable",
            valueEnum: ENABLE
        },
        {
            title: '操作',
            dataIndex: 'option',
            search: false,
            width:"250px",
            align: 'center',
            render: (_, row, index, action) => <>
                <Button type="link" onClick={() => {
                    setState(pre => ({ ...pre, id: row.id }))
                    contralModal(true)
                    form.setFieldsValue({ ...row, price: row.price / 100 });
                }}>编辑</Button>
                <Link to={{ pathname: "/admin/adhibition/combo/adhibition", state: row.id }}>
                    <Button type="link">套餐应用</Button>
                </Link>
                <Button type="link" onClick={() => DeletePackage(row.id)}>删除</Button>
                <Button type="link" onClick={() => PackageEnable(row.enable, row.id)}>{row.enable ? "下架" : "发布"}</Button>
            </>
        }
    ]
    const [state, setState] = useState({
        id: null,
        visible: false
    })
    const actionRef = React.useRef<ActionType>() as any;
    const [form] = Form.useForm();
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            console.log(values);
            await GetPackage({
                method: state.id ? "put" : "post",
                ...values,
                price: values.price * 100,
                id: state.id
            })
            message.success("操作成功！");
            actionRef.current?.reloadAndRest();
            contralModal(false)
        })
    }
    const PackageEnable = async (enable, id) => {
        await PKenable({
            enable: !enable,
            id
        })
        message.success("操作成功！");
        actionRef.current?.reloadAndRest();
    }
    const DeletePackage = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await GetPackage({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current?.reloadAndRest();
            }
        });
    }
    const contralModal = (flag) => {
        form.resetFields()
        setState((pre) => ({ ...pre, visible: flag }))
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row => row.id}
            request={GetPackage}
            options={false}
            columns={columns}
            toolBarRender={() => [
                <><Button
                    type="primary"
                    key="primary"
                    icon={<PlusOutlined />}
                    onClick={() => {
                        contralModal(true)
                        setState(pre=>({...pre,id:null}))
                    }}
                >
                    新增
                </Button>
                </>
            ]}
        />
        <Modal
            title={state.id ? "编辑套餐" : "添加套餐"}
            visible={state.visible}
            width={480}
            onOk={onSubmit}
            maskClosable={false}
            onCancel={() => contralModal(false)}
        >
            <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
                <Form.Item label="套餐名" name="name" rules={[{ required: true, message: "请输入套餐名" }]}>
                    <Input placeholder="请输入套餐名" />
                </Form.Item>
                <Form.Item label="包含房间数" name="house_count" rules={[{ required: true, message: "请输入包含房间数" }]}>
                    <InputNumber  placeholder="请输入包含房间数" style={{ width: '100%' }}
                        min={1} />
                </Form.Item>
                <Form.Item label="价格" name="price" rules={[{ required: true, message: "请输入价格" }]}>
                    <InputNumber addonAfter="元" placeholder="请输入价格" style={{ width: '100%' }} min={1} />
                </Form.Item>
                <Form.Item label="套餐简介" name="desc">
                    <TextArea placeholder="请输入套餐简介" autoSize={{minRows: 4, maxRows: 6 }} />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Combo