import React, { useState } from "react";
import type { ActionType } from "@ant-design/pro-table";
import ProTable from "@ant-design/pro-table";
import { PlusOutlined } from "@ant-design/icons";
import { Button, Form, Modal, Input, InputNumber, message } from "antd";
import { Msg_packageOption } from "../../../services/package";
import TextArea from "antd/lib/input/TextArea";

const Msg_package = () => {
    const actionRef = React.useRef<ActionType>() as any;
    const columns: any = [
        {
            title: "套餐名称",
            dataIndex: "name",
        },
        {
            title: "短信条数",
            dataIndex: "msg_count",
        },
        {
            title: "套餐价格",
            dataIndex: "price",
            render: (_, row) => row.price / 100
        },
        {
            title: "套餐描述",
            dataIndex: "comment",
            ellipsis: true
        },
        {
            title: "操作",
            dataIndex: "option",
            align: "center",
            render: (_, row) => <>
                <Button type="link" onClick={() => {
                    setState(pre => ({ ...pre, id: row.id }))
                    contralModal(true)
                    form.setFieldsValue({ ...row, price: row.price / 100 });
                }}>编辑</Button>
                <Button type="link" onClick={() => DeletePackage(row.id)}>删除</Button>
            </>
        }
    ];
    const [state, setState] = useState({
        id: null,
        visible: false
    });
    const [form] = Form.useForm();
    const contralModal = (flag) => {
        form.resetFields()
        setState((pre) => ({ ...pre, visible: flag }))
    };
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            await Msg_packageOption({
                method: state.id ? "put" : "post",
                ...values,
                price: values.price * 100,
                id: state.id
            })
            message.success("操作成功！");
            actionRef.current?.reloadAndRest();
            contralModal(false)
        })
    }
    const DeletePackage = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await Msg_packageOption({ method: "delete", id });
                message.success("操作成功！");
                actionRef.current?.reloadAndRest();
            }
        });
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={Msg_packageOption}
            options={false}
            search={false}
            columns={columns}
            toolBarRender={() => [
                <><Button
                    type="primary"
                    key="primary"
                    icon={<PlusOutlined />}
                    onClick={() => {
                        contralModal(true)
                        setState(pre=>({...pre,id:null}))
                    }}
                >
                    新增
                </Button>
                </>
            ]}
        />
        <Modal
            title={state.id ? "编辑套餐" : "添加套餐"}
            visible={state.visible}
            width={480}
            onOk={onSubmit}
            maskClosable={false}
            onCancel={() => contralModal(false)}
        >
            <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
                <Form.Item label="套餐名" name="name" rules={[{ required: true, message: "请输入套餐名" }]}>
                    <Input placeholder="请输入套餐名" />
                </Form.Item>
                <Form.Item label="短信条数" name="msg_count" rules={[{ required: true, message: "请输入短信条数" }]}>
                    <InputNumber placeholder="请输入短信条数" style={{ width: '100%' }}
                        min={1} />
                </Form.Item>
                <Form.Item label="价格" name="price" rules={[{ required: true, message: "请输入价格" }]}>
                    <InputNumber addonAfter="元" placeholder="请输入价格" style={{ width: '100%' }} min={1} />
                </Form.Item>
                <Form.Item label="套餐简介" name="comment" >
                    <TextArea placeholder="请输入套餐简介" autoSize={{ minRows: 4, maxRows: 6 }} />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Msg_package