import React, { useEffect, useState } from "react"
import type { ActionType } from "@ant-design/pro-table"
import ProTable from "@ant-design/pro-table"
import { withRouter } from "react-router"
import { Form, Button, Modal, Input, Select, message, Upload, Row, Dropdown, Menu, Checkbox } from "antd"
import { GateList, GateIn, GateOut, GateRecycle, GateTemplate, GateImport, GateProtocols } from "../../services/gate"
import { getLocalTime } from "../../utils/utils"
import { GetGardenList } from "../../services/api"
import './index.scss'
import { Link } from "react-router-dom"

const CheckboxGroup = Checkbox.Group;
const DoorControl = () => {
    const support = {
        1: { text: "支持", status: "Success" },
        2: { text: "不支持", status: "Error" }
    }
    const columns: any = [
        {
            title: '设备序列号',
            align: 'center',
            search: false,
            dataIndex: 'sn',
            ellipsis: true,
        },
        {
            title: '设备名',
            align: 'center',
            search: false,
            dataIndex: 'device_name',
            ellipsis: true,
        },
        {
            title: '厂家',
            align: 'center',
            valueType: 'select',
            search: false,
            dataIndex: 'manufactor',
            ellipsis: true,
        },
        {
            title: '授权KEY',
            search: false,
            align: 'center',
            dataIndex: 'auth_key',
            ellipsis: true,
        },
        {
            title: '人脸',
            align: 'center',
            search: false,
            dataIndex: "pic_support",
            valueEnum: support
        },
        {
            title: '二维码',
            align: 'center',
            search: false,
            dataIndex: "qcode_support",
            valueEnum: support
        },
        {
            title: 'IC卡',
            align: 'center',
            search: false,
            dataIndex: "card_support",
            valueEnum: support
        },
        {
            title: '协议',
            align: 'center',
            search: false,
            dataIndex: 'protocol_desc',
            ellipsis: true,
        },
        // {
        //     title: '入库时间',
        //     align: 'center',
        //     search: false
        // },
        {
            title: "状态",
            search: true,
            align: 'center',
            dataIndex: 'out',
            valueEnum: {
                0: { text: '全部', value: 0 },
                1: { text: '已出库', value: 1 },
                2: { text: '未出库', value: 2 }
            },
            render: (_, row) => (
                <span>{row.out_time > 0 ? '已出库' : '未出库'}</span>
            )
        },
        {
            title: '出库人',
            align: 'center',
            search: false,
            dataIndex: "out_user"
        },
        {
            title: '出库时间',
            align: 'center',
            search: false,
            dataIndex: 'out_time',
            ellipsis: true,
             render: (_, row) => <span>{row.out_time ? getLocalTime(row.out_time) : '-'}</span>
        },
        {
            title: '接收小区',
            align: 'center',
            search: false,
            dataIndex: 'garden_name'
        },
        {
            title: '运行状态',
            search: false,
            dataIndex: 'status',
            valueEnum: {
                1: { text: '在线' },
                2: { text: '离线' },
            }
        },
        {
            title: '操作',
            dataIndex: 'option',
            search: false,
            width: '190px',
            align: 'center',
            render: (_, row, index, action) =>
                <div className="optionSpan" key={row.id}>
                    <Link to={{ pathname: '/admin/device/door/detail', state: row }}> <span style={{color:"#03BB7A"}}>详情</span></Link>
                    {row.out_time > 0 ? <span className="disClick">出库</span> :
                        <span style={{color:"#03BB7A"}}
                            onClick={() => {
                                setState(prevState => ({ ...prevState, outVisible: true, device_id: row.device_id }))
                            }}
                        >出库</span>
                    }
                    <span style={{color:"#03BB7A"}}
                        onClick={() => Gaterecycle(row.device_id)}
                    >回收</span>
                    <span style={{color:"#03BB7A"}}
                        onClick={() => GateDelete(row.device_id)}
                    >删除</span>
                </div>
        }
    ]
    const actionRef = React.useRef<ActionType>() as any
    const { Option } = Select
    const [form] = Form.useForm()
    const [state, setState]: any = useState({
        visible: false,
        exportVisible: false,
        outVisible: false,
        garden_name: '',
    })
    const [dropVisible, setDropVisible]: any = useState(false)
    const [garden, setGarden]: any = useState([])
    let uploadFile: any = null
    const [protocol, setprotocol]: any = useState([]);
    const getProtocal = async () => {
        const { data } = await GateProtocols();
        setprotocol(data)
    }
    useEffect(() => {
        getProtocal()
    }, [])
    const onSubmit = () => {
        form.validateFields().then(async (value) => {
            console.log(value);
            await GateIn({ ...value })
            message.success('操作成功')
            actionRef.current.reloadAndRest()
            form.resetFields()
            // close modal
            setState(prevState => ({ ...prevState, visible: false }))
        })
    }
    //门禁出库
    const onGateOut = () => {
        form.validateFields(['garden_name']).then(async (value) => {
            const device_id = state.device_id
            const garden_id = value.garden_name - 0
            console.log(device_id, garden_id);
            await GateOut({ garden_id, device_id })
            message.success('操作成功')
            actionRef.current.reloadAndRest()
            form.resetFields()
            setState(prevState => ({ ...prevState, outVisible: false, device_id: null, garden_name: '' }))
        })
    }
    //门禁回收
    const Gaterecycle = (device_id) => {
        Modal.confirm({
            title: "门禁回收",
            content: "你确定回收这条记录吗？",
            onOk: async () => {
                await GateRecycle({ device_id });
                message.success("操作成功！");
                actionRef.current.reload();
            }
        });
    }
    //门禁删除
    const GateDelete = (id) => {
        Modal.confirm({
            title: "门禁删除",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await GateList({ method: 'delete', device_id: id });
                message.success("操作成功！");
                actionRef.current.reload();
            }
        });
    }
    const getTemplate = async () => {
        const { data } = await GateTemplate()
        window.open(data.url)
    }
    const handleInput = () => {
        const { garden_name } = state
        if (garden_name !== '') {
            GetGardenList({ garden_name, page: -1, pageSize: -1, not_approved: false }).then(res => {
                setGarden(res.list)
                setDropVisible(true)
            })
        }
    }
    const getValue = (e) => {
        const garden_name = e.target.value
        setState(pre => ({ ...pre, garden_name }))
    }
    const menu = (
        <Menu onClick={(e) => {
            const [{ garden_name, garden_addr }] = garden.filter(item => item.id == e.key)
            form.setFieldsValue({ garden_name: e.key })
            setState(pre => ({ ...pre, garden_name: `${garden_name}(${garden_addr})` }))
        }}>
            {
                garden.length > 0 ?
                    garden.map(item => {
                        return <Menu.Item key={item.id}>{`${item.garden_name}  (${item.garden_addr})`}
                        </Menu.Item>
                    }) : <Menu.Item disabled key={'disabled'}>{`    未查到对应小区`}</Menu.Item>
            }
        </Menu>
    );
    const closeOut = () => {
        setState(pre => ({ ...pre, outVisible: false, garden_name: '' }))
        setDropVisible(false)
    }
    const plainOptions = ['人脸', '二维码', 'IC卡'];
    const [checkedList, setCheckedList] = useState([]);
    const onChange = (list => {
        setCheckedList(list);
    });
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row => row.device_id}
            request={GateList}
            bordered={true}
            options={false}
            columns={columns}
            toolBarRender={() => [
                <><Button
                    type="primary"
                    key="primary"
                    style={{ borderRadius: "5px", marginRight: '5px' }}
                    onClick={() => {
                        setState(pre => ({ ...pre, visible: true }));
                        form.resetFields();
                        setCheckedList([]);
                    }}
                >
                    入库
                </Button><Button
                    type="primary"
                    key="primary2"
                    style={{ borderRadius: "5px" }}
                    onClick={() => {
                        setState(prevState => ({ ...prevState, exportVisible: true }))
                    }}
                >批量入库</Button></>
            ]}
        />
        {/* 门禁入库 */}
        <Modal
            title='门禁入库'
            visible={state.visible}
            onOk={onSubmit}
            onCancel={() => setState(pre => ({ ...pre, visible: false }))}
        >
            <Form
                labelCol={{ span: 5 }}
                wrapperCol={{ span: 15 }}
                name="gate-form"
                form={form}
            // initialValues={{ gate_type: 1, protocol: 1 }}
            >
                <Form.Item label='设备序列号' name='sn' rules={[{ required: true, message: '请输入设备序列号' }]}>
                    <Input placeholder="请输入设备序列号" ></Input>
                </Form.Item>
                <Form.Item label='设备名' name='device_name' rules={[{ required: true, message: '请输入设备名' }]}>
                    <Input placeholder="请输入设备名"></Input>
                </Form.Item>
                <Form.Item label='厂家' name='manufactor' rules={[{ required: true, message: '请选择厂家' }]}>
                    <Input placeholder="请输入厂家" />
                </Form.Item>
                <Form.Item label='授权KEY' name='auth_key' rules={[{ required: true, message: '请输入授权KEY' }]}>
                    <Input placeholder="请输入授权KEY"></Input>
                </Form.Item>
                {/* <Form.Item label='设备类型' name='gate_type' rules={[{ required: true, message: '请选择设备类型' }]}>
                    <Select placeholder="请选择设备类型">
                        <Option value={1}>二维码门禁</Option>
                        <Option value={2}>人脸识别门禁</Option>
                    </Select>
                </Form.Item> */}
                <Form.Item label='协议' name='protocol' rules={[{ required: true, message: '请选择协议' }]}>
                    <Select options={protocol}
                        placeholder="请选择协议"
                        fieldNames={{ label: "desc", value: "protocol" }}
                        onChange={(val) => {
                            let face = protocol.filter(item => item.protocol == val);
                            let checkedList: any = [];
                            face.map(item => {
                                if (item.qcode_support == 1) {
                                    checkedList.push("二维码");
                                }
                                if (item.card_support == 1) {
                                    checkedList.push("IC卡");
                                }
                                if (item.face_support == 1) {
                                    checkedList.push("人脸");
                                }
                            })
                            setCheckedList(checkedList);
                        }}
                    >
                    </Select>
                </Form.Item>
                <Form.Item label="开门类型">
                    <CheckboxGroup options={plainOptions} value={checkedList} onChange={onChange} disabled />
                </Form.Item>
            </Form>
        </Modal>
        {/* 门禁批量入库 */}
        <Modal
            title='批量入库'
            visible={state.exportVisible}
            onOk={async () => {
                if (!uploadFile) message.error('请先选择文件！')
                const files = new FormData()
                files.append('file', uploadFile)
                await GateImport({
                    file: files
                })
                message.success('上传成功')
                actionRef.current.reloadAndRest()
                setState(prevState => ({
                    ...prevState,
                    exportVisible: false
                }))
                uploadFile = null
            }}
            destroyOnClose={true}
            onCancel={() => {
                setState(prevState => ({
                    ...prevState,
                    exportVisible: false
                }))
                uploadFile = null
            }}
            okText="保存"
        >
            <Form
                labelCol={{ span: 5 }}
                wrapperCol={{ span: 16 }}
            >
                <Form.Item label='选择文件'>
                    <Upload
                        beforeUpload={file => {
                            uploadFile = file
                            return false
                        }}
                        maxCount={1}
                    >
                        <Button>选择文件</Button>
                    </Upload>
                </Form.Item>
                <Form.Item label='下载模板'>
                    请先下载 <span className='link-primary'
                        onClick={getTemplate}
                    >导入模板</span> 准备数据后，上传导入
                </Form.Item>
            </Form>
        </Modal>
        {/* 门禁出库 */}
        <Modal
            title='门禁出库'
            visible={state.outVisible}
            okText='保存'
            onOk={onGateOut}
            onCancel={closeOut}
        >
            <Form labelCol={{ span: 5 }}
                wrapperCol={{ span: 15 }}
                name="gate-form"
                form={form}
            >
                <Form.Item name="garden_name" label="出库小区" rules={[{ required: true, message: '请选择出库小区', }]}>
                    <Dropdown
                        overlay={menu}
                        visible={dropVisible}
                        trigger={['contextMenu']}
                        onVisibleChange={visible => setDropVisible(visible)}
                        overlayClassName='rollSelect'
                    >
                        <Input placeholder="请输入要出库的小区名"
                            onChange={getValue}
                            value={state.garden_name}
                            addonAfter={<span className="searchSpan" onClick={handleInput}>搜索</span>}
                            allowClear
                        ></Input>
                    </Dropdown>
                </Form.Item>
            </Form>
        </Modal>
    </>)
}
export default withRouter(DoorControl)