import React, { FC } from 'react'
import {
  Form,
  Input,
  Button,
  Row,
  Col,
  Upload,
  Select,
  InputNumber,
  message,
  Image
} from 'antd'
import { UploadOutlined, LeftOutlined } from '@ant-design/icons'
import { CreateCompany } from '../../services/api'
import { useHistory } from "react-router"
import './index.scss'

const proveForm = [
  {
    label: '法人代表',
    name: 'legal_person'
  },
  {
    label: '详细地址',
    name: 'company_addr'
  },
  {
    label: '统一社会信用代码',
    name: 'social_code'
  }
]
const accountForm = [
  {
    label: '用户名',
    name: 'username'
  },
  {
    label: '密码',
    name: 'password'
  }
]
const basicInfoForm = [
  {
    label: '申请人',
    name: 'applicant'
  },
  {
    label: '申请人联系电话',
    name: 'applicant_phone'
  },
  {
    label: '企业名称',
    name: 'company_name'
  },
  {
    label: '企业联系电话',
    name: 'company_phone'
  },
  {
    label: '申请人职务',
    name: 'applicant_duty'
  },
]

const AddCompany: FC = () => {
  const uploadProps: any = {
    name: "file",
    action: "/api/v1/upload",
    headers: {
      token: sessionStorage.getItem('area-token')
    },
    listType: "picture",
    maxCount: 1
  }
  const [form]: any = Form.useForm()
  const history = useHistory()
  const location = history.location
  const state: any = location.state
  
  const handleCreateCompany = () => {
    form.validateFields()
      .then(async values => {
       const business_license= values.business_license.fileList[0].response.data
       const applicant_identification = values.applicant_identification.fileList[0].response.data
        await CreateCompany({
          ...values,
          business_license,
          applicant_identification
        })
        message.success('添加成功')
        history.goBack()
      })
    return
  }

  return (
    <div className="custom-form-box">
      <div className='goBack'>
        <Button type='primary' icon={<LeftOutlined />}
          onClick={history.goBack}
        >返回</Button>
      </div>
      <Form
        form={form}
        name='form'
        labelCol={{ span: 8 }}
        wrapperCol={{ span: 9 }}
        initialValues={{ remember: true }}
        labelAlign={'right'}
      >
        <Row>
          <Col span={12}>
            <div className='form-group-title'>基本信息</div>
            {
              basicInfoForm.map(item => (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  required
                  key={item.name}
                  rules={[{ required: true, message: `请输入${item.label}` }]}
                >
                  {state ? <span>{
                    Object.keys(state).map(key => {
                      if (item.name == key) {
                        return state[key]
                      }
                    })
                  }</span> : <Input placeholder={`请输入${item.label}`} />}
                </Form.Item>
              ))
            }
            <Form.Item label='身份证明' wrapperCol={{ span: 10 }} name='applicant_identification'
              rules={[{ required: true, message: '请上传身份证明' }]}
            >
              {state ? <Image
                width={100}
                src={state.applicant_identification}
                key={state.applicant_identification}
              /> :
                <Upload {...uploadProps}>
                  <Button style={{ width: '100%' }} icon={<UploadOutlined />}>选择文件</Button>
                </Upload>}
            </Form.Item>
          </Col>
          <Col span={12}>
            <div className='form-group-title'>账户信息</div>
            {
              accountForm.map(item => (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.label}
                  required
                  rules={[{ required: true, message: `请输入${item.label}` }]}
                >
                  {state ? <span>{
                    Object.keys(state).map(key => {
                      if (item.name == key) {
                        return state[key]
                      }
                    })
                  }</span> : <Input placeholder={`请输入${item.label}`} />}
                  {/* {item.label=='密码'?<Input.Password placeholder={`请输入${item.label}`}/>:  <Input placeholder={`请输入${item.label}`} />} */}

                </Form.Item>
              ))
            }
          </Col>
        </Row>
        <Row className='form-group'>
          <Col span={12}>
            <div className='form-group-title'>资质信息</div>
            {
              proveForm.map(item => (
                <Form.Item
                  label={item.label}
                  name={item.name}
                  key={item.name}
                  required
                  rules={[{ required: true, message: `请输入${item.label}` }]}
                >
                  {state ? <span>{
                    Object.keys(state).map(key => {
                      if (item.name == key) {
                        return state[key]
                      }
                    })
                  }</span> :
                    <Input placeholder={`请输入${item.label}`} />}
                </Form.Item>
              ))
            }
            <Form.Item
              label='证件类型'
              wrapperCol={{ span: 10 }}
              valuePropName='option'
              name='license_type'
              rules={[{ required: true,message:'请选择证件类型'}]}
            >
              {state ?
                <Select style={{ width: 180 }} value={state.license_type} disabled>
                  <Select.Option value={1}>多证合一营业执照</Select.Option>
                  <Select.Option value={2}>普通营业执照</Select.Option>
                </Select>
                :
                <Select style={{ width: 180 }} placeholder='多证合一营业执照'>
                  <Select.Option value={1}>多证合一营业执照</Select.Option>
                  <Select.Option value={2}>普通营业执照</Select.Option>
                </Select>}
            </Form.Item>
            <Form.Item label='营业执照' wrapperCol={{ span: 10 }} name="business_license"
              rules={[{ required: true, message: '请上传营业执照' }]}
            >
              {state ?
                <Image
                  width={100}
                  src={state.business_license}
                />
                :
                <Upload {...uploadProps}>
                  <Button style={{ width: '100%' }} icon={<UploadOutlined />}>选择文件</Button>
                </Upload>}
            </Form.Item>
          </Col>
        </Row>
        <Row className='form-group'>
          <Col span={12}>
            <div className='form-group-title'>权限信息</div>
            <Form.Item
              label="免费小区个数"
              name="free_garden_count"
              required
              rules={[{ required: true, message: '请输入小区个数!' }]}
              wrapperCol={{ span: 8 }}
            >
              {state ?
                <span>{state.free_garden_count}</span>
                :
                <InputNumber style={{ width: '140px' }} min={0} placeholder='请输入小区个数' />
              }
            </Form.Item>
          </Col>
        </Row>
        {state ? null :
          <div className='submitButton'>
            <Button type="primary" size='large' onClick={() => {
              handleCreateCompany()
            }}>
              添加
            </Button>
          </div>
        }
      </Form>
    </div>
  )
}

export default AddCompany
