import React, { useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, InputNumber, Row, Image, message, Input } from 'antd'
import { PlusOutlined } from '@ant-design/icons'
import { BasicInfoForm, ProveForm } from './map'
import { GetCompanyList } from '../../services/api'
import { Company_Approve, Company_free_garden } from '../../services/examine'
import { Link } from 'react-router-dom'

const CompanyList: React.FC = (props: any) => {
  // @ts-ignore
  const columns: any = [
    {
      title: '申请人',
      width: '70px',
      dataIndex: 'applicant',
      search: false
    },
    {
      title: '申请人联系电话',
      dataIndex: 'applicant_phone',
      search: false
    },
    {
      title: '企业名称',
      dataIndex: 'company_name',
    },
    {
      title: '企业联系电话',
      dataIndex: 'company_phone',
      search: false,
    },
    {
      title: '申请人职务',
      dataIndex: 'applicant_duty',
      search: false,
    },
    {
      title: '身份证明',
      dataIndex: 'applicant_identification',
      search: false,
      render: (_, row, index, action) => [
        <Image
          width={100}
          key={row.id}
          src={row.applicant_identification}
        />
      ]
    },
    {
      title: '申请时间',
      dataIndex: 'created_at',
      search: false,
    },
    {
      title: '审核状态',
      dataIndex: 'approve_status',
      valueType: 'select',
      valueEnum: {
        0: { text: '所有', status: 'Default' },
        1: { text: '待审核', status: 'Processing' },
        2: { text: '通过', status: 'Success', },
        3: { text: '未通过', status: 'Error' },
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: '200px',
      align: "center",
      render: (_, row, index, action) => (
        <div key={row.id}>
          {[1].includes(row.approve_status) ? <Button type='link' onClick={() => {
            setRowData(row)
            setState(pre => ({ ...pre, examineVisible: true }))
          }}>审核</Button> : <Button type='link' disabled>审核</Button>}
          <Link to={{ pathname: '/admin/examine/company/detail', state: row }}><Button type='link'>详情</Button></Link>
          <Link to={{ pathname: '/admin/examine/company/package', state: row }}>
            <Button type='link'>套餐</Button>
          </Link>
        </div>
      )
    }
  ]
  const [state, setState] = React.useState({
    examineVisible: false,
  })
  const [rowData, setRowData] = useState({})
  const [form]: any = Form.useForm()

  const actionRef = React.useRef<ActionType>();
  const footer = <>
    <Button id='checkPass' onClick={() => checkPass(false)}>不通过</Button>
    <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
  </>
  const checkPass = (status) => {
    const id = rowData['id']
    form.validateFields().then(async value => {
      const { feedback } = value
      await Company_Approve({ id, status, feedback })
      message.success('操作成功')
      setState(pre => ({ ...pre, examineVisible: false }))
      actionRef.current?.reload()
    })
  }
  return (
    <React.Fragment>
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        options={false}
        search={{ labelWidth: 120 }}
        request={GetCompanyList}
        toolBarRender={() => [
          <Link to={"/admin/examine/company/add"}>
            <Button key="button" icon={<PlusOutlined />} type="primary">
              添加物业公司
            </Button>
          </Link>
        ]}
        columns={columns}
      />
      <Modal
        title='审核'
        visible={state.examineVisible}
        cancelText='不通过'
        okText='通过'
        footer={footer}
        onCancel={() => setState(pre => ({ ...pre, examineVisible: false }))}
      >
        <Form
          labelCol={{ span: 7 }}
          wrapperCol={{ span: 9 }}
          form={form}
        >
          <Row>
            <div className='examine-form-title'>基本信息</div>
            {
              BasicInfoForm.map(item => (
                <Form.Item
                  style={{ width: '100%' }}
                  label={item.label}
                  key={item.name}
                  required
                >
                  {rowData[item.name]}
                </Form.Item>
              ))
            }
          </Row>
          <Row>
            <div className='examine-form-title'>资质信息</div>
            {
              ProveForm.map(item => (
                <Form.Item
                  style={{ width: '100%' }}
                  label={item.label}
                  key={item.name}
                  required
                >
                  {rowData[item.name]}
                </Form.Item>
              ))
            }
          </Row>
          <Row>
            <Form.Item name='feedback' label='审核意见' rules={[{ required: true, message: '请输入审核意见' }]} style={{ width: '100%' }}>
              <Input.TextArea autoSize={{ minRows: 2, maxRows: 6 }} placeholder='请输入审核意见'></Input.TextArea>
            </Form.Item>
          </Row>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default CompanyList