import React, { useEffect, useState } from "react";
import { useHistory } from "react-router";
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Form, InputNumber, Modal, Select, message } from "antd";
import { PlusOutlined } from '@ant-design/icons'
import { CompanyPackage, AddPackage, RenewPackage } from "../../services/companyPackage";
import { GetPackage } from "../../services/package";
import "./package.scss"
const Package = () => {
    const history = useHistory()
    const location = history.location
    const data: any = location.state;
    const columns: any = [
        {
            title: "套餐名",
            align: "center",
            dataIndex: "name"
        },
        {
            title: "周期（年）",
            align: "center",
            dataIndex: "period"
        },
        {
            title: "购买时间",
            align: "center",
            dataIndex: "expire_at"
        },
        {
            title: "操作",
            dataIndex: "option",
            align: "center",
            render: (_, row) => row.garden_id==0?<Button type="link" disabled>续费</Button>:
            <Button type="link" onClick={() => {
                contralModal2(true)
                setrenewInfo(row)
            }}>续费</Button>
        }
    ]
    const actionRef = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [renewForm] = Form.useForm();
    const [options, setOptions] = useState([]);
    const [packageList, setPackageList]: any = useState([]);
    const [renewInfo, setrenewInfo]: any = useState({})
    const [state, setState] = useState({
        visible: false,
        renewVisible: false
    })
    const contralModal = (flag) => {
        setState(pre => ({ ...pre, visible: flag }))
    }
    const contralModal2 = (flag) => {
        setState(pre => ({ ...pre, renewVisible: flag }))
    }
    useEffect(() => {
        GetPackage({ page: 1, page_size: 9999, enable: 1 }).then(res => {
            setPackageList(res.data);
            const data = res.data.map(item => {
                return { label: item.name, value: item.id }
            })
            setOptions(data)
        })
    }, [])
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            const { package_id, period } = values;
            let amount;
            packageList.map(item => {
                if (item.id == package_id) {
                    amount = item.price * period
                }
            })
            await AddPackage({
                ...values,
                cid: data.id,
                company_name: data.company_name,
                amount
            })
            message.success('操作成功')
            contralModal(false)
            actionRef.current?.reload()
        })
    }
    const periodHandle = (type, way) => {
        let value = way.getFieldValue('period')
        if (type == 'add') {
            way.setFieldsValue({ 'period': value + 1 })
        } else {
            if (value !== 1) {
                way.setFieldsValue({ 'period': value - 1 })
            }
        }
    }
    const onRenewSubmit = () => {
        renewForm.validateFields().then(async (values) => {
            const { period } = values;
            const { garden_id, package_id, price } = renewInfo;
            const amount = period * price;
            await RenewPackage({
                period,
                garden_id,
                package_id,
                amount
            })
            message.success('操作成功')
            contralModal2(false)
            actionRef.current?.reload()
        })
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            options={false}
            params={{ cid: data.id }}
            rowKey={row => row.id}
            search={false}
            request={CompanyPackage}
            toolBarRender={() => [
                <>
                    <Button type="primary" icon={<PlusOutlined />} onClick={() => {
                        contralModal(true)
                        form.resetFields()
                    }}>添加</Button>
                    <Button type="primary" onClick={history.goBack}>返回</Button>
                </>
            ]}
            columns={columns}
        />
        <Modal
            title='新增套餐'
            visible={state.visible}
            width={480}
            onOk={onSubmit}
            onCancel={() => contralModal(false)}
        >
            <Form form={form} wrapperCol={{ span: 10 }}
                initialValues={{ period: 1 }}
            >
                <Form.Item name="package_id" label="套餐" rules={[{ required: true, message: "请选择套餐" }]} >
                    <Select options={options} placeholder="请选择套餐"></Select>
                </Form.Item>
                <Form.Item name="period" label="周期" rules={[{ required: true, message: "请输入周期" }]}>
                    <InputNumber addonBefore={<div onClick={() => periodHandle('sub', form)}>-</div>}
                        addonAfter={<div onClick={() => periodHandle('add', form)}>+</div>} controls={false} min={1} />
                </Form.Item>
            </Form>
        </Modal>

        <Modal
            title='续费'
            visible={state.renewVisible}
            width={480}
            onOk={onRenewSubmit}
            onCancel={() => contralModal2(false)}
        >
            <Form form={renewForm} labelCol={{ span: 4 }} wrapperCol={{ span: 10 }}
                initialValues={{ period: 1 }}
            >
                <Form.Item label="套餐">
                    <span>{renewInfo.name}</span>
                </Form.Item>
                <Form.Item name="period" label="周期" rules={[{ required: true, message: "请输入周期" }]}>
                    <InputNumber addonBefore={<div onClick={() => periodHandle('sub', renewForm)}>-</div>}
                        addonAfter={<div onClick={() => periodHandle('add', renewForm)}>+</div>} controls={false} min={1} />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Package