import ProTable from "@ant-design/pro-table";
import { Button, Modal, message, Form, Input } from "antd";
import type { ActionType } from '@ant-design/pro-table'
import React, { useEffect, useState } from "react";
import { withRouter } from "react-router";
import { GardenInfoAmend } from "../../services/garden";
const GardenApplyFor = () => {
    const columns: any = [
        {
            title: "小区名称",
            dataIndex: "garden_name",
            search: false,
        },
        {
            title: "字段名",
            dataIndex: 'field_name',
            search: false,
            render: (_, row) => row.list.map((item,index) => {
                return <span style={{ display: 'block' }} key={index}>{item.field_name}</span>
            })
        },
        {
            title: "修改前",
            dataIndex: "field_value_src",
            search: false,
            render: (_, row) => row.list.map((item,index) => {
                return <span style={{ display: 'block' }} key={index}>{item.field_value_src}</span>
            })
        },
        {
            title: "修改后",
            dataIndex: 'field_value_dst',
            search: false,
            render: (_, row) => row.list.map((item,index) => {
                return <span style={{ display: 'block' }} key={index}>{item.field_value_dst}</span>
            })
        },
        {
            title: "状态",
            dataIndex: "status",
            search: true,
            valueType: 'select',
            valueEnum: {
                0: { text: '所有', status: 'Default' },
                1: { text: '待审核', status: 'Processing' },
                2: { text: '通过', status: 'Success', },
                3: { text: '未通过', status: 'Error' },
            }
        },
        {
            title: "操作",
            dataIndex: "option",
            search: false,
            align: "center",
            render: (_, row) => <>
                <Button type="link" disabled={row.status==2?true:false} onClick={() => {
                    form.resetFields()
                    setState(pre => ({ ...pre, id: row.id }))
                    closeModal(true)
                }}>审核</Button>
            </>
        }
    ]
    const actionRef = React.useRef<ActionType>();
    const [form] = Form.useForm()
    const [state, setState] = useState({
        visible: false,
        id: null
    })
    const footer = <>
        <Button id='checkPass' onClick={() => checkPass(false)}>不通过</Button>
        <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
    </>
    const checkPass = (status) => {
        form.validateFields().then(async value => {
            const { id } = state
            const { feedback } = value
            await GardenInfoAmend({ method: "put", id, status, feedback })
            message.success('操作成功')
            actionRef.current?.reload()
            closeModal(false)
        })
    }
    const closeModal = (flag) => {
        setState(pre => ({ ...pre, visible: flag }))
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row=>row.id}
            options={false}
            request={GardenInfoAmend}
            columns={columns}
        />
        <Modal
            title='小区关键信息修改'
            visible={state.visible}
            cancelText='不通过'
            okText='通过'
            footer={footer}
            onCancel={() => closeModal(false)}
        >
            <Form form={form}>
                <Form.Item label='详情' name='feedback' rules={[{ required: true, message: "请输入内容" }]}>
                    <Input.TextArea rows={3} cols={5} placeholder="请输入通过或者拒绝原因"></Input.TextArea>
                </Form.Item>
            </Form>
        </Modal>
    </>)
}
export default withRouter(GardenApplyFor)