import * as React from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Select, Card, message, Input } from 'antd'
import { GetGardenList, GetProvinceCityArea, GetCompanyList } from '../../services/api'
import { GetGardenStreet, GardenChange, GardenCheck, GardenEnable } from '../../services/garden'
import './index.scss'

const GardenList: React.FC = (props: any) => {
  // @ts-ignore
  const columns: any = [
    {
      title: '小区名称',
      dataIndex: 'garden_name',
      search: true,
    },
    {
      title: '小区地址',
      dataIndex: 'garden_addr',
      search: false,
      ellipsis: true,
    },
    {
      title: '物业公司',
      dataIndex: 'cid',
      search: false,
      render: (_, row) => <span>
        {companyList.map(item => {
          if (item.id == row.cid) {
            return item.company_name
          }
        })}</span>
    },
    {
      title: '物业联系人',
      dataIndex: 'property_person',
      search: false
    },
    {
      title: '手机号',
      dataIndex: 'property_phone',
      search: false,
      ellipsis: true,
    },
    {
      title: '社区',
      dataIndex: 'committee',
      search: false,
      ellipsis: true,
    },
    {
      title: '街道',
      dataIndex: 'street',
      search: false,
      ellipsis: true,
    }, {
      title: "审核状态",
      dataIndex: "status",
      search: false,
      valueEnum: {
        1: { text: '待审核', status: 'Processing' },
        2: { text: '通过', status: 'Success', },
        3: { text: "未通过", status: "Error" }
      }
    },
    {
      title: "审核状态",
      dataIndex: "not_approved",
      search: true,
      hideInTable: true,
      valueEnum: {
        true: "待审批或未通过的数据",
        false: "审批通过的数据"
      }
    },
    {
      title: '操作',
      dataIndex: 'option',
      search: false,
      width: "25%",
      align: 'center',
      render: (_, row, index, action) => <>
        {row.status == 1 ?
          <Button type='link' onClick={() => {
            form.resetFields()
            closeModal(true)
            setState(pre => ({ ...pre, id: row.id }))
          }}>小区审核</Button>
          :
          <>
            <Button type='link' disabled>小区审核</Button>
          </>
        }
        {row.status == 2 ? <>
          <Button type='link' onClick={() =>
            gardenEnable(row.id, row.enable)}>{row.enable ? "停用" : "启用"}</Button>
          <Button type='link' onClick={() => {
            setState(pre => ({ ...pre, visible: !state.visible, garden_id: row.id }))
            form.resetFields()
          }}>修改所属物业公司</Button>
        </> :
          <><Button type='link' disabled>{row.enable ? "停用" : "启用"}</Button>
            <Button type='link' disabled>修改所属物业公司</Button></>
        }
      </>
    }
  ]
  const [state, setState] = React.useState({
    visible: false,
    examineVisible: false,
    garden_id: null,
    checkVisible: false,
    id: ''
  })
  const [searchCase, setSearchCase]: any = React.useState({
    committee_code: '',
    street_code: '',
    not_approved: ''
  })
  const [areaData, setAreaData] = React.useState({
    province_list: [],
    city_list: [],
    area_list: []
  })
  // cache
  const [areaDataCache, setAreaDataCache] = React.useState({
    province_list: [],
    city_list: [],
    area_list: []
  })
  const [streetData, setStreetData] = React.useState({
    committee_list: [],
    street_list: []
  })
  // cache
  const [streetDataAche, setStreetDataAche] = React.useState({
    committee_list: [],
    street_list: []
  })
  const [dataSource, setDataSource] = React.useState([])
  const [companyList, setCompany]: any = React.useState([])
  const actionRef: any = React.useRef<ActionType>();
  const [form] = Form.useForm()
  // React.useEffect(() => {
  //   GetProvinceCityArea({}).then(res => {
  //     setAreaDataCache(res.data)
  //     setAreaData(pre => ({
  //       ...pre,
  //       province_list: res.data.province_list
  //     }))
  //   })
  // }, [])
  React.useEffect(() => {
    GetCompanyList({ approve_status: 3 }).then(res => {
      setCompany(res.data)
    })
  }, [])
  const controlModal = () => {
    setState(pre => ({ ...pre, visible: !state.visible, garden_id: null }))
  }

  const searchGarden = () => {
    const { committee_code, street_code, not_approved } = searchCase
    GetGardenList({ committee_code, street_code, not_approved, page: 1, page_size: 2 }).then(res => {
      setDataSource(res.data)
    })
  }
  const getStreet_committee = (value) => {
    form.resetFields(['stree', 'committee_code'])
    setStreetDataAche(pre => ({ ...pre, committee_list: [] }))
    GetGardenStreet({ area_code: value }).then(res => {
      setStreetData(res.Data)
    })
  }
  const getCommittee_code = (value) => {
    form.resetFields(['committee_code'])
    setSearchCase(pre => ({ ...pre, street_code: value, committee_code: '' }))
    setStreetDataAche(pre => ({
      ...pre,
      committee_list: streetData.committee_list.filter((item: any) => item.street_code === value)
    }))
  }
  const editCompany = () => {
    form.validateFields(['cid']).then(async value => {
      const { garden_id } = state
      const { cid } = value
      await GardenChange({ garden_id, cid })
      message.success('修改成功')
      controlModal()
      actionRef.current.reload();
    })
  }
  const restClick = () => {
    form.resetFields(['province', 'city', 'area', 'city', 'stree', 'committee_code', 'not_approved'])
    setAreaData(pre => ({ ...pre, area_list: [], city_list: [] }))
    setStreetData(pre => ({ ...pre, street_list: [] }))
    setStreetDataAche(pre => ({ ...pre, committee_list: [] }))
    setSearchCase({
      committee_code: '',
      street_code: '',
      not_approved: ''
    })
  }
  const gardenEnable = async (garden_id, enable) => {
    const res = await GardenEnable({ garden_id, enable: !enable });
    message.success('操作成功')
    actionRef.current.reload();
  }
  const selectButton = <>
    <Form
      layout={'inline'}
      form={form}
    >
      <Form.Item name='province'>
        <Select
          placeholder='请选择省份'
          style={{ width: 130, marginBottom: 10 }}
          onChange={
            (value) => {
              form.resetFields(['city', 'area', 'stree', 'committee_code'])
              setAreaData(pre => ({ ...pre, area_list: [] }))
              setStreetData(pre => ({ ...pre, street_list: [] }))
              setStreetDataAche(pre => ({ ...pre, committee_list: [] }))
              setAreaData(pre => ({
                ...pre,
                city_list: areaDataCache.city_list.filter((item: any) => item.province_code === value)
              }))
            }
          }>
          {
            areaData.province_list.map((province: any) => {
              return <Select.Option value={province.code} key={province.code}>{province.name}</Select.Option>
            })
          }
        </Select>
      </Form.Item>
      <Form.Item name='city'>
        <Select
          placeholder='请选择城市'
          style={{ width: 130, marginBottom: 10 }}
          onChange={
            (value) => {
              form.resetFields(['area', 'stree', 'committee_code'])
              setStreetData(pre => ({ ...pre, street_list: [] }))
              setStreetDataAche(pre => ({ ...pre, committee_list: [] }))
              setAreaData(pre => ({
                ...pre,
                area_list: areaDataCache.area_list.filter((item: any) => item.city_code === value)
              }))
            }
          }
        >
          {
            areaData.city_list.map((item: any) => {
              return <Select.Option value={item.code} key={item.code}>{item.name}</Select.Option>
            })
          }
        </Select>
      </Form.Item>
      <Form.Item name='area'>
        <Select placeholder='请选择区域' style={{ width: 130, marginBottom: 10 }}
          onChange={(value) => getStreet_committee(value)}
        >
          {
            areaData.area_list.map((item: any) => {
              return <Select.Option value={item.code} key={item.name}>{item.name}</Select.Option>
            })
          }
        </Select>
      </Form.Item>
      <Form.Item name='stree'>
        <Select placeholder='请选择街道' style={{ width: 130, marginBottom: 10 }} onChange={(value) => getCommittee_code(value)}>
          {
            streetData.street_list.map((item: any) => {
              return <Select.Option value={item.code} key={item.name}>{item.name}</Select.Option>
            })
          }
        </Select>
      </Form.Item>
      <Form.Item name='committee_code'>
        <Select placeholder='请选择社区' style={{ width: 130, marginBottom: 10 }} onChange={(e) => setSearchCase(pre => ({ ...pre, committee_code: e }))}>
          {
            streetDataAche.committee_list.map((item: any) => {
              return <Select.Option value={item.code} key={item.name}>{item.name}</Select.Option>
            })
          }
        </Select>
      </Form.Item>
      <Form.Item name="not_approved">
        <Select placeholder="请选择审核状态" style={{ width: 130, marginBottom: 10 }} onChange={(value) => setSearchCase(pre => ({ ...pre, not_approved: value }))
        }>
          <Select.Option value="false">通过</Select.Option>
          <Select.Option value="true">未通过/待审核</Select.Option>
        </Select>
      </Form.Item>
    </Form>
  </>
  const footer = <>
    <Button id='checkPass' onClick={() => checkPass(false)}>不通过</Button>
    <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
  </>
  const closeModal = (flag) => {
    setState(pre => ({ ...pre, checkVisible: flag, id: '' }))
  }
  const checkPass = (status) => {
    form.validateFields(['feedback']).then(async value => {
      const { id } = state
      const { feedback } = value
      await GardenCheck({ id, status, feedback })
      message.success('操作成功')
      closeModal(false)
      actionRef.current.reload();
    })
  }
  return (
    <React.Fragment>
      {/* <Card className='searchButton'>
        {selectButton}
        <div className='footerButton'>
          <Button type='primary' onClick={restClick}>重置</Button>
          <Button type='primary' onClick={searchGarden}>查询</Button>
        </div>
      </Card> */}
      <ProTable
        actionRef={actionRef}
        rowKey="id"
        options={false}
        search={{
          collapsed: false, collapseRender: () => false,
          span: 6, labelWidth: 'auto',
          // optionRender: ({ searchText, resetText }, { form }, dom) => [
          //   <Button
          //     key="searchText"
          //     type="primary"
          //     onClick={() => {
          //        console.log(searchText,resetText,form,dom);
          //       form?.submit();
          //     }}
          //   >
          //     {searchText}
          //   </Button>,
          //   <Button
          //     key="resetText"
          //     onClick={() => {
          //       form?.resetFields();
          //     }}
          //   >
          //     {resetText}
          //   </Button>
          // ]
        }}
        request={GetGardenList}
        // dataSource={dataSource}
        // toolBarRender={() => [selectButton, <>
        //   <Button type='primary' onClick={restClick}>重置</Button>
        //   <Button type='primary' onClick={searchGarden}>查询</Button>
        // </>]}
        columns={columns}
      />
      <Modal
        visible={state.visible}
        title='修改小区所属物业公司'
        onOk={() => editCompany()}
        onCancel={controlModal}
      >
        <Form form={form}
        >
          <Form.Item label='所属物业公司' name='cid' rules={[{ required: true, message: `请选择物业公司` }]}>
            <Select placeholder='请选择'>
              {companyList.map(item => {
                return <Select.Option value={item.id} key={item.id}>
                  {item.company_name}
                </Select.Option>
              })}
            </Select>
          </Form.Item>
        </Form>
      </Modal>
      <Modal
        title='小区审核'
        visible={state.checkVisible}
        cancelText='不通过'
        okText='通过'
        footer={footer}
        onCancel={() => closeModal(false)}
      >
        <Form form={form}>
          <Form.Item label='备注' name='feedback'>
            <Input.TextArea rows={3} cols={5} placeholder="请输入通过或者拒绝原因"></Input.TextArea>
          </Form.Item>
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default GardenList