import React, { useState } from "react";
import { Button, Modal, Form, Input, message, InputNumber } from "antd";
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import moment from 'moment'
import { OrderApplication, ApplicationAmount } from "../../services/order";

const Order_adhibition = () => {
    const columns: any = [
        {
            title: "小区名",
            align: "center",
            search: false,
            dataIndex: "garden_name"
        },
        {
            title: "应用名",
            align: "center",
            dataIndex: "name",
            search: false
        },
        {
            title: "购买时间",
            align: "center",
            dataIndex: "created_at",
            search: false,
            render:(_,row)=>moment(row.created_at * 1000).format("YYYY-MM-DD HH:MM:SS")
        },
        {
            title: "订单金额（元）",
            align: "center",
            dataIndex: "amount",
            search: false,
            render: (_, row) => (row.amount / 100).toFixed(2)
        },
        {
            title: "状态",
            align: "center",
            dataIndex: "status",
            valueType: 'select',
            valueEnum: {
                1: { text: '待认证', status: 'Processing' },
                2: { text: '已通过', status: 'Success', },
                3: { text: '未通过', status: 'Error' },
            },
        },
        {
            title: "操作",
            align: "center",
            dataIndex: "option",
            search: false,
            render: (_, row) => <>
                <Button type="link" disabled={row.status==1?false:true} onClick={() => {
                    priceform.setFieldsValue({amount:row.amount/100})
                    setState(pre => ({ ...pre, visible: true, order_id: row.order_id }))
                }}>改价</Button>
                <Button type="link" disabled={row.status==1?false:true} onClick={() => {
                    form.resetFields()
                    setState(pre => ({ ...pre, checkVisible: true, order_id: row.order_id }))
                }}>审核</Button>
            </>
        },
    ]
    const actionRef = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [priceform] = Form.useForm();
    const [state, setState] = useState({
        order_id: null,
        checkVisible: false,
        visible: false
    })
    const footer = <>
        <Button danger onClick={() => checkPass(false)}>不通过</Button>
        <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
    </>
    const checkPass = (status) => {
        console.log(status);

        form.validateFields().then(async (values) => {
            const { order_id } = state;
            await OrderApplication({ method: 'put', order_id, ...values, status })
            message.success('操作成功')
            setState(pre => ({ ...pre, checkVisible: false }))
            actionRef.current?.reload()
        })
    }
    const amountSubmit = () => {
        priceform.validateFields().then(async (values) => {
            const { order_id } = state;
            const { amount } = values;
            await ApplicationAmount({ order_id, amount: amount * 100 });
            message.success('操作成功')
            setState(pre => ({ ...pre, visible: false }))
            actionRef.current?.reload()
        })
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row => row.order_id}
            options={false}
            search={{ labelWidth: 120 }}
            request={OrderApplication}
            columns={columns}
        />
        <Modal
            title="审核"
            visible={state.checkVisible}
            cancelText='不通过'
            okText='通过'
            footer={footer}
            onCancel={() => setState(pre => ({ ...pre, checkVisible: false }))}
        >
            <Form form={form}>
                <Form.Item name='feedback' label='审核意见' rules={[{ required: true, message: '请输入审核意见' }]} style={{ width: '100%' }}>
                    <Input.TextArea autoSize={{ minRows: 4, maxRows: 6 }} placeholder='请输入审核意见'></Input.TextArea>
                </Form.Item>
            </Form>
        </Modal>
        <Modal
            title="改价"
            visible={state.visible}
            width={300}
            onOk={amountSubmit}
            onCancel={() => setState(pre => ({ ...pre, visible: false }))}
        >
            <Form form={priceform}>
                <Form.Item label="价格" name="amount" rules={[{ required: true, message: "请输入价格" }]} >
                    <InputNumber min={1} addonAfter="￥" />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Order_adhibition