import React, { useState } from "react";
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Link } from "react-router-dom";
import { Button,Form,Modal,Input,message } from "antd";
import { ApplicationMsg } from "../../services/order";


const OrderMsg_package = () => {
    const columns: any = [
        {
            title: "小区名",
            align: "center",
            search: false,
            dataIndex: "garden_name"
        },
        {
            title: "套餐名",
            align: "center",
            search: false,
            dataIndex: "name"
        },
        {
            title: "订单金额",
            align: "center",
            search: false,
            dataIndex: "amount",
            render: (_, row) => (row.amount / 100).toFixed(2)
        },
        {
            title: "状态",
            align: "center",
            dataIndex: "status",
            valueEnum: {
                1: { text: "待审核", status: "Processing" },
                2: { text: "已通过", status: "Success" },
                3: { text: "未通过", status: "Error" }
            }
        },
        {
            title: "操作",
            align: "center",
            search: false,
            dataIndex: "option",
            render: (_, row) => <>
                <Link to={{ pathname: "/admin/order/msg_package/detail", state: row }}>
                    <Button type="link">详情</Button>
                </Link>
                {<Button type="link" disabled={row.status==1?false:true}
                onClick={()=>setState(pre => ({ ...pre, visible: true, order_id: row.order_id }))}
                >审核</Button>}
            </>
        }
    ]
    const actionRef: any = React.useRef<ActionType>();
    const [form] =Form.useForm();
    const [state, setState] = useState({
        visible: false,
        order_id:null
    })
    const footer = <>
        <Button danger onClick={() => checkPass(false)}>不通过</Button>
        <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
    </>
    const checkPass = (status) => {
        form.validateFields().then(async (values) => {
            const { order_id } = state;
            await ApplicationMsg({ method: 'put', order_id, ...values, status })
            message.success('操作成功')
            setState(pre => ({ ...pre, visible: false }))
            actionRef.current?.reload()
        })
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey="order_id"
            request={ApplicationMsg}
            columns={columns}
        />
        <Modal
            title="审核"
            visible={state.visible}
            cancelText='不通过'
            okText='通过'
            footer={footer}
            onCancel={() => setState(pre => ({ ...pre, visible: false }))}
        >
            <Form form={form}>
                <Form.Item name='feedback' label='审核意见' style={{ width: '100%' }}>
                    <Input.TextArea autoSize={{ minRows: 4, maxRows: 6 }} placeholder='请输入审核意见'></Input.TextArea>
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default OrderMsg_package