import { Button, Modal, Form, InputNumber, message, Input } from "antd";
import React, { useState } from "react";
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import moment from 'moment'
import { OrderPackge, PackageAmount } from "../../services/order";
import { RenewPackage } from "../../services/companyPackage";

const Order_package = () => {
    const columns: any = [
        {
            title: "物业公司",
            align: "center",
            dataIndex: "company_name"
        },
        {
            title: "套餐名",
            align: "center",
            dataIndex: "name",
            search: false
        },
        {
            title: "周期（年）",
            align: "center",
            dataIndex: "period",
            search: false
        },
        {
            title: "购买时间",
            align: "center",
            dataIndex: "created_at",
            search: false,
            render:(_,row)=>moment(row.created_at * 1000).format("YYYY-MM-DD HH:MM:SS")
        },
        {
            title: "单价（元）",
            align: "center",
            dataIndex: "price",
            search: false,
            render: (_, row) => row.price / 100
        },
        {
            title: "订单金额（元）",
            align: "center",
            dataIndex: "amount",
            search: false,
            render: (_, row) => row.amount / 100
        },
        {
            title: "状态",
            align: "center",
            dataIndex: "status",
            valueType: 'select',
            valueEnum: {
                1: { text: '待认证', status: 'Processing' },
                2: { text: '已通过', status: 'Success', },
                3: { text: '未通过', status: 'Error' },
            },
        },
        {
            title: "操作",
            align: "center",
            dataIndex: "option",
            search: false,
            render: (_, row) => <>
                {row.status == 1 ? <>
                    <Button type="link" onClick={() => {
                        form.resetFields()
                        setState(pre => ({ ...pre, visible: true, order_id: row.order_id }))
                    }}>改价</Button>
                    <Button type="link" onClick={() => {
                        setState(pre => ({ ...pre, checkVisible: true, order_id: row.order_id }))
                    }}>审核</Button>
                    <Button type="link" disabled>续费</Button>
                </> :
                    <>
                        <Button type="link" disabled>改价</Button>
                        <Button type="link" disabled>审核</Button>
                        <Button type="link" onClick={() => {
                            setState(pre => ({ ...pre, renewVisible: true }));
                            setrenewInfo(row)
                        }} >续费</Button>
                    </>
                }
            </>
        },
    ]
    const actionRef = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [renewInfo, setrenewInfo]: any = useState([])
    const [state, setState] = useState({
        visible: false,
        order_id: null,
        checkVisible: false,
        renewVisible: false
    })
    const amountSubmit = () => {
        form.validateFields().then(async (values) => {
            const { order_id } = state;
            const { amount } = values;
            await PackageAmount({ order_id, amount: amount * 100 });
            message.success('操作成功')
            setState(pre => ({ ...pre, visible: false }))
            actionRef.current?.reload()
        })
    }
    const footer = <>
        <Button danger onClick={() => checkPass(false)}>不通过</Button>
        <Button type='primary' onClick={() => checkPass(true)}>通过</Button>
    </>
    const checkPass = (status) => {
        form.validateFields().then(async (values) => {
            const { order_id } = state;
            await OrderPackge({ method: 'put', order_id, ...values, status })
            message.success('操作成功')
            setState(pre => ({ ...pre, checkVisible: false }))
            actionRef.current?.reload()
        })
    }
    const onRenewSubmit = () => {
        form.validateFields().then(async (values) => {
            const { period } = values;
            const { garden_id, package_id, price } = renewInfo;
            const amount = period * price;
            if (garden_id == 0) {
             message.info("请先绑定小区")
            } else {
                await RenewPackage({
                    period,
                    garden_id,
                    package_id,
                    amount
                })
                message.success('操作成功')
                setState(pre => ({ ...pre, renewVisible: false }))
                actionRef.current?.reload()
            }
        })
    }
    const periodHandle = (type) => {
        let value = form.getFieldValue('period')
        if (type == 'add') {
            form.setFieldsValue({ 'period': value + 1 })
        } else {
            if (value !== 1) {
                form.setFieldsValue({ 'period': value - 1 })
            }
        }
    }
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey={row => row.order_id}
            options={false}
            search={{ labelWidth: 120 }}
            request={OrderPackge}
            columns={columns}
        />
        <Modal
            title="改价"
            visible={state.visible}
            width={300}
            onOk={amountSubmit}
            onCancel={() => setState(pre => ({ ...pre, visible: false }))}
        >
            <Form form={form}>
                <Form.Item label="价格" name="amount" rules={[{ required: true, message: "请输入价格" }]} >
                    <InputNumber min={1} addonAfter="￥" />
                </Form.Item>
            </Form>
        </Modal>
        <Modal
            title="审核"
            visible={state.checkVisible}
            cancelText='不通过'
            okText='通过'
            footer={footer}
            onCancel={() => setState(pre => ({ ...pre, checkVisible: false }))}
        >
            <Form form={form}>
                <Form.Item name='feedback' label='审核意见' rules={[{ required: true, message: '请输入审核意见' }]} style={{ width: '100%' }}>
                    <Input.TextArea autoSize={{ minRows: 4, maxRows: 6 }} placeholder='请输入审核意见'></Input.TextArea>
                </Form.Item>
            </Form>
        </Modal>
        <Modal
            title='续费'
            visible={state.renewVisible}
            width={480}
            onOk={onRenewSubmit}
            onCancel={() => setState(pre => ({ ...pre, renewVisible: false }))}
        >
            <Form form={form} labelCol={{ span: 4 }} wrapperCol={{ span: 10 }}
                initialValues={{ period: 1 }}
            >
                <Form.Item label="套餐">
                    <span>{renewInfo.name}</span>
                </Form.Item>
                <Form.Item name="period" label="周期" rules={[{ required: true, message: "请输入周期" }]}>
                    <InputNumber addonBefore={<div onClick={() => periodHandle('sub')}>-</div>}
                        addonAfter={<div onClick={() => periodHandle('add')}>+</div>} controls={false} min={1} />
                </Form.Item>
            </Form>
        </Modal>
    </>)
}

export default Order_package