import React, { useEffect, useState } from 'react'
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { Button, Modal, Form, Input, Switch, message } from 'antd'
import { PlusOutlined, ExclamationCircleOutlined } from '@ant-design/icons'
import { RoleOption, RoleEnable } from '../../services/role'
import { ListDataTransform } from '../../utils/utils'
import './list.scss'

const RoleList: React.FC = () => {
  const actionRef: any = React.useRef<ActionType>();
  const [state, setState]: any = useState({
    visible: false,
    pcode: '',
    method: '',
    code: '',
    expandedRowKeys: []
  })
  const columns: any = [
    {
      title: '权限名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '小程序组件路径',
      dataIndex: 'applete_path',
      key: 'applete_path',
      align:'center'
    },
    {
      title: '组件路径',
      dataIndex: 'path',
      key: 'path',
      align:'center'
    },
    {
      title: '路由',
      dataIndex: 'router',
      key: 'router',
      align:'center'
    },
    {
      title: "状态",
      dataIndex: "enable",
      key: 'enable',
      valueEnum: {
        1: { text: '发布', status: 'Success' },
        2: { text: '下架', status: 'Error' }
      },
      align:'center'
    },
    {
      title: '操作',
      dataIndex: 'option',
      valueType: 'option',
      width: 300,
      align: 'center',
      render: (_, record: any) => <>
        <Button
          type='link'
          key={record.id}
          onClick={() => {
            setState({
              visible: true,
              pcode: record.code,
              method: 'post'
            })
            console.log(record.code);

            form.resetFields()
          }}
        >添加子节点</Button>
        <Button
          type='link'
          onClick={() => {
            setState({
              visible: true,
              method: 'put',
              code: record.code
            })
            form.setFieldsValue(record)
          }}
        >修改</Button>
        <Button
          type='link'
          onClick={() => {
            Modal.confirm({
              title: '确认删除吗？',
              icon: <ExclamationCircleOutlined />,
              content: '点击确认后会删除该权限',
              okText: '确认',
              okType: 'danger',
              cancelText: '取消',
              onOk() {
                RoleOption({
                  method: 'delete',
                  code: record.code
                }).then(res => {
                  message.success('操作成功')
                  actionRef.current.reload()
                })
              },
            })
          }}
        >删除</Button>
        {record.enable == 1 ? <Button type='link' onClick={() => permissionEnable(2, record)}>下架</Button> :
          <Button type='link' onClick={() => permissionEnable(1, record)}>发布</Button>}
      </>
    }
  ]
  const [form] = Form.useForm()
  const permissionEnable = (enable, record) => {
    const {code} = record
    Modal.confirm({
      title: `确认${enable == 1 ? '发布' : '下架'}`,
      icon: <ExclamationCircleOutlined />,
      onOk() {
        RoleEnable({  code,enable }).then(res => {
          message.success('操作成功')
          actionRef.current.reload();
          expandedRowRender(record)
        })
      }
    })

  }
  const RoleController = () => {
    form.validateFields().then(async values => {
      const enable = values.enable == true ? 1 : 2
      await RoleOption({ ...state, ...values, enable })
      message.success('操作成功！')
      setState({ visible: false, pcode: '', method: '', code: '' })
      form.resetFields()
      actionRef.current.reload()
    })
  }

  const roleFormItems = [
    {
      label: '权限名称',
      name: 'name'
    },
    {
      label: '路由',
      name: 'router'
    },
    {
      label: '组件路径',
      name: 'path'
    }, {
      label: '小程序组件路径',
      name: 'applete_path'
    }
  ]
  const expandedRowRender = (erecord) => {
    ListDataTransform(erecord)
    return (
      <ProTable
        tableClassName='displayNone'
        indentSize={60}
        rowKey={row => row.code}
        columns={columns}
        headerTitle={false}
        search={false}
        options={false}
        dataSource={erecord.childs}
        pagination={false}
      />
    );
  };
  const onExpand = (expanded: any, record: any) => {
    let temp: any = []
    if (expanded) {
      temp.push(record.code)
    }
    setState(pre => ({
      ...pre,
      expandedRowKeys: temp
    }))
  }

  return (
    <React.Fragment>
      <ProTable
        headerTitle="权限列表"
        actionRef={actionRef}
        rowKey={record => record.code}
        search={false}
        options={false}
        request={RoleOption}
        expandable={{ onExpand,indentSize:20 }}
        expandedRowRender={(erecord) => expandedRowRender(erecord)}
        expandedRowKeys={state.expandedRowKeys}
        toolBarRender={() => [
          <Button
            type="primary"
            key="primary"
            onClick={() => {
              setState({
                visible: true,
                method: 'post'
              })
              form.resetFields()
            }}
          >
            <PlusOutlined /> 新建
          </Button>,
        ]}
        columns={columns}
      />
      <Modal
        title={state.method === 'post' ? '添加节点' : '修改权限'}
        width={400}
        visible={state.visible}
        onOk={() => RoleController()}
        onCancel={() => setState(pre => ({ ...pre, visible: false }))}
      >
        <Form form={form}
          labelAlign='left'
          labelCol={{ span: 8 }}
          initialValues={{ enable: true }}
        >
          {
            roleFormItems.map(item => (
              <Form.Item
                label={item.label}
                name={item.name}
                required
                key={item.label}
                rules={[{ required: true, message: `请输入${item.label}` }]}
              >
                <Input placeholder={`请输入${item.label}`} />
              </Form.Item>
            ))
          }
          {state.method === 'post' ?
            <Form.Item label='是否发布' name='enable' required valuePropName="checked">
              <Switch defaultChecked />
            </Form.Item> :
            ''
          }
        </Form>
      </Modal>
    </React.Fragment>
  )
}

export default RoleList