import React, { useState } from "react";
import { MaterialOption, EnableMaterial } from "../../services/material";
import type { ActionType } from '@ant-design/pro-table'
import ProTable from '@ant-design/pro-table'
import { PlusOutlined } from "@ant-design/icons";
import { Button, Form, message, Modal, Select, Upload, Image, Popconfirm } from "antd";
import { getBase64 } from "../../utils/utils";
import moment from 'moment'

const SetImage = () => {
    const options = [
        { label: "小程序首页", value: 1 },
        { label: "小程序租房", value: 2 },
        { label: "管家默认图（男）", value: 3 },
        { label: "管家默认图（女）", value: 4 }
    ]
    const mtype = {
        1: "小程序首页",
        2: "小程序租房",
        3: "管家默认图（男）",
        4: "管家默认图（女）"
    }
    const columns: any = [
        {
            title: '类型',
            dataIndex: 'mtype',
            align: "center",
            valueEnum: mtype
        },
        {
            title: '预览',
            dataIndex: 'pic',
            align: "center",
            render: (_, row) => <Image height="100px" width="100px" src={row.pic} />
        },
        {
            title: '创建时间',
            dataIndex: 'created_at',
            align: "center",
            render: (_, row: any) => <span>{moment.unix(row.created_at).format('YYYY-MM-DD HH:MM:SS')}</span>,
        },
        {
            title: '发布状态',
            dataIndex: 'enable',
            align: "center",
            valueEnum: {
                1: { text: "已发布", status: "Success" },
                2: { text: "未发布", status: "Error" }
            }
        },
        {
            title: '操作',
            dataIndex: 'options',
            align: "center",
            render: (_, row) => <>
                <Button type="link" onClick={() => deleteImage(row.id)}>删除</Button>
                <Button type="link" onClick={() => editImage(row)}>更新</Button>
                <Popconfirm
                    title={`确定${row.enable == 1 ? "下架" : "发布"}吗？`}
                    onConfirm={() => enableImage(row.id, row.enable)}
                    okText="确定"
                    cancelText="取消"
                >
                    <Button type="link">{row.enable == 1 ? "下架" : "发布"}</Button>
                </Popconfirm>
            </>
        },
    ]
    const actionRef: any = React.useRef<ActionType>();
    const [form] = Form.useForm();
    const [state, setstate]: any = useState({
        id: "",
        visible: false
    })
    const addImage = () => {
        form.resetFields();
        setFileList([]);
        setstate({ id: "", visible: true });
    }
    const editImage = (row) => {
        setstate({ id: row.id, visible: true });
        form.setFieldsValue(row);
        setFileList([{
            uid: '-1',
            name: 'image.png',
            status: 'done',
            url: row.pic,
        },])
    }
    const deleteImage = (id) => {
        Modal.confirm({
            title: "删除记录",
            content: "你确定删除这条记录吗？",
            onOk: async () => {
                await MaterialOption({ method: 'delete', id });
                message.success("操作成功！");
                actionRef.current.reload();
            }
        });
    }

    const enableImage = async (id, enable) => {
        if (enable == 1) {
            await EnableMaterial({ id, enable: 2 });
        } else {
            await EnableMaterial({ id, enable: 1 });
        }
        message.success("操作成功！");
        actionRef.current.reload();
    }
    const onSubmit = () => {
        form.validateFields().then(async (values) => {
            await MaterialOption({
                method: state.id ? "put" : "post",
                id: state.id,
                ...values
            });
            message.success("操作成功")
            setstate((pre) => ({ ...pre, visible: false }))
            actionRef.current?.reloadAndRest();
        })
    }
    const [fileList, setFileList]: any = useState([]);
    const [previewVisible, setPreviewVisible] = useState(false);
    const [previewImage, setPreviewImage] = useState();
    const [previewTitle, setPreviewTitle] = useState('');
    const handleChange = (info) => {
        setFileList(info.fileList);
        if (info.file.status === 'done') {
            const { data } = info.file.response;
            form.setFieldsValue({ pic: data })
        }
        if (info.fileList.length == 0) {
            form.setFieldsValue({ pic: "" })
        }
    };
    const handlePreview = async (file) => {
        if (!file.url && !file.preview) {
            file.preview = await getBase64(file.originFileObj);
        }
        setPreviewImage(file.url || file.preview);
        setPreviewVisible(true);
        setPreviewTitle(file.name || file.url.substring(file.url.lastIndexOf('/') + 1));
    };
    const handleCancel = () => setPreviewVisible(false);
    const token: any = sessionStorage.getItem('area-token')
    return (<>
        <ProTable
            actionRef={actionRef}
            rowKey="id"
            request={MaterialOption}
            columns={columns}
            search={false}
            toolBarRender={() => [
                <><Button
                    type="primary"
                    key="primary"
                    icon={<PlusOutlined />}
                    onClick={addImage}
                >
                    新增
                </Button></>
            ]}
        />
        <Modal
            visible={state.visible}
            title={state.id ? "更新素材" : "新建素材"}
            onOk={onSubmit}
            maskClosable={false}
            onCancel={() => setstate((pre) => ({ ...pre, visible: false }))}
        >
            <Form labelCol={{ span: 5 }} wrapperCol={{ span: 15 }} form={form}>
                <Form.Item label="类型" name="mtype" rules={[{ required: true, message: "请选择类型" }]}>
                    <Select placeholder="请选择类型" options={options}></Select>
                </Form.Item>
                <Form.Item label="图片" name="pic" rules={[{ required: true, message: "请上传图片" }]}>
                    <Upload
                        name="file"
                        className="avatar-uploader"
                        // action="http://localhost:3001/api/v1/upload"
                        action="http://47.108.135.38:30001/api/v1/upload"
                        listType="picture-card"
                        headers={{
                            token
                        }}
                        fileList={fileList}
                        onChange={handleChange}
                        onPreview={handlePreview}
                    >
                        {fileList.length < 1 && '+ Upload'}
                    </Upload>
                </Form.Item>
            </Form>
        </Modal>
        <Modal visible={previewVisible} title={previewTitle} footer={null} onCancel={handleCancel}>
            <img
                alt="example"
                style={{
                    width: '100%',
                }}
                src={previewImage} />
        </Modal>
    </>)
}
export default SetImage